# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTransitRouterRouteTableResult',
    'AwaitableGetTransitRouterRouteTableResult',
    'get_transit_router_route_table',
    'get_transit_router_route_table_output',
]

@pulumi.output_type
class GetTransitRouterRouteTableResult:
    """
    A collection of values returned by getTransitRouterRouteTable.
    """
    def __init__(__self__, created_time=None, description=None, id=None, in_route_policy_table_id=None, out_route_policy_table_id=None, status=None, tags=None, transit_router_id=None, transit_router_route_table_id=None, transit_router_route_table_name=None, transit_router_route_table_type=None, updated_time=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if in_route_policy_table_id and not isinstance(in_route_policy_table_id, str):
            raise TypeError("Expected argument 'in_route_policy_table_id' to be a str")
        pulumi.set(__self__, "in_route_policy_table_id", in_route_policy_table_id)
        if out_route_policy_table_id and not isinstance(out_route_policy_table_id, str):
            raise TypeError("Expected argument 'out_route_policy_table_id' to be a str")
        pulumi.set(__self__, "out_route_policy_table_id", out_route_policy_table_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if transit_router_id and not isinstance(transit_router_id, str):
            raise TypeError("Expected argument 'transit_router_id' to be a str")
        pulumi.set(__self__, "transit_router_id", transit_router_id)
        if transit_router_route_table_id and not isinstance(transit_router_route_table_id, str):
            raise TypeError("Expected argument 'transit_router_route_table_id' to be a str")
        pulumi.set(__self__, "transit_router_route_table_id", transit_router_route_table_id)
        if transit_router_route_table_name and not isinstance(transit_router_route_table_name, str):
            raise TypeError("Expected argument 'transit_router_route_table_name' to be a str")
        pulumi.set(__self__, "transit_router_route_table_name", transit_router_route_table_name)
        if transit_router_route_table_type and not isinstance(transit_router_route_table_type, str):
            raise TypeError("Expected argument 'transit_router_route_table_type' to be a str")
        pulumi.set(__self__, "transit_router_route_table_type", transit_router_route_table_type)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        TR路由表的创建时间
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        TR路由表的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="inRoutePolicyTableId")
    def in_route_policy_table_id(self) -> builtins.str:
        """
        TR路由表关联的收方向路由策略的ID
        """
        return pulumi.get(self, "in_route_policy_table_id")

    @property
    @pulumi.getter(name="outRoutePolicyTableId")
    def out_route_policy_table_id(self) -> builtins.str:
        """
        TR路由表关联的发方向路由策略的ID
        """
        return pulumi.get(self, "out_route_policy_table_id")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        TR路由表的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetTransitRouterRouteTableTagResult']:
        """
        TR路由表的标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> builtins.str:
        """
        中转路由器实例的ID
        """
        return pulumi.get(self, "transit_router_id")

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> builtins.str:
        """
        TR路由表的ID
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @property
    @pulumi.getter(name="transitRouterRouteTableName")
    def transit_router_route_table_name(self) -> builtins.str:
        """
        TR路由表的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为TR路由表的ID
        """
        return pulumi.get(self, "transit_router_route_table_name")

    @property
    @pulumi.getter(name="transitRouterRouteTableType")
    def transit_router_route_table_type(self) -> builtins.str:
        """
        TR路由表的类型。System：系统路由表。Custom：自定义路由表。
        """
        return pulumi.get(self, "transit_router_route_table_type")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        TR路由表的最近操作时间
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetTransitRouterRouteTableResult(GetTransitRouterRouteTableResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTransitRouterRouteTableResult(
            created_time=self.created_time,
            description=self.description,
            id=self.id,
            in_route_policy_table_id=self.in_route_policy_table_id,
            out_route_policy_table_id=self.out_route_policy_table_id,
            status=self.status,
            tags=self.tags,
            transit_router_id=self.transit_router_id,
            transit_router_route_table_id=self.transit_router_route_table_id,
            transit_router_route_table_name=self.transit_router_route_table_name,
            transit_router_route_table_type=self.transit_router_route_table_type,
            updated_time=self.updated_time)


def get_transit_router_route_table(id: Optional[builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTransitRouterRouteTableResult:
    """
    Data Source schema for Byteplus::TransitRouter::TransitRouterRouteTable


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:transitrouter/getTransitRouterRouteTable:getTransitRouterRouteTable', __args__, opts=opts, typ=GetTransitRouterRouteTableResult).value

    return AwaitableGetTransitRouterRouteTableResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        in_route_policy_table_id=pulumi.get(__ret__, 'in_route_policy_table_id'),
        out_route_policy_table_id=pulumi.get(__ret__, 'out_route_policy_table_id'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        transit_router_id=pulumi.get(__ret__, 'transit_router_id'),
        transit_router_route_table_id=pulumi.get(__ret__, 'transit_router_route_table_id'),
        transit_router_route_table_name=pulumi.get(__ret__, 'transit_router_route_table_name'),
        transit_router_route_table_type=pulumi.get(__ret__, 'transit_router_route_table_type'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_transit_router_route_table_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTransitRouterRouteTableResult]:
    """
    Data Source schema for Byteplus::TransitRouter::TransitRouterRouteTable


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:transitrouter/getTransitRouterRouteTable:getTransitRouterRouteTable', __args__, opts=opts, typ=GetTransitRouterRouteTableResult)
    return __ret__.apply(lambda __response__: GetTransitRouterRouteTableResult(
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        in_route_policy_table_id=pulumi.get(__response__, 'in_route_policy_table_id'),
        out_route_policy_table_id=pulumi.get(__response__, 'out_route_policy_table_id'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        transit_router_id=pulumi.get(__response__, 'transit_router_id'),
        transit_router_route_table_id=pulumi.get(__response__, 'transit_router_route_table_id'),
        transit_router_route_table_name=pulumi.get(__response__, 'transit_router_route_table_name'),
        transit_router_route_table_type=pulumi.get(__response__, 'transit_router_route_table_type'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'WorkspaceInstanceType',
    'WorkspaceQuota',
    'WorkspaceTag',
    'WorkspaceUsage',
    'GetWorkspaceInstanceTypeResult',
    'GetWorkspaceQuotaResult',
    'GetWorkspaceTagResult',
    'GetWorkspaceUsageResult',
]

@pulumi.output_type
class WorkspaceInstanceType(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "activeSeries":
            suggest = "active_series"
        elif key == "availabilityZoneReplicas":
            suggest = "availability_zone_replicas"
        elif key == "downsamplingPeriods":
            suggest = "downsampling_periods"
        elif key == "ingestSamplesPerSecond":
            suggest = "ingest_samples_per_second"
        elif key == "queryConcurrency":
            suggest = "query_concurrency"
        elif key == "queryPerSecond":
            suggest = "query_per_second"
        elif key == "replicasPerZone":
            suggest = "replicas_per_zone"
        elif key == "retentionPeriod":
            suggest = "retention_period"
        elif key == "scanSamplesPerSecond":
            suggest = "scan_samples_per_second"
        elif key == "scanSeriesPerSecond":
            suggest = "scan_series_per_second"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkspaceInstanceType. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkspaceInstanceType.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkspaceInstanceType.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 active_series: Optional[builtins.int] = None,
                 availability_zone_replicas: Optional[builtins.int] = None,
                 downsampling_periods: Optional[Sequence[builtins.str]] = None,
                 ingest_samples_per_second: Optional[builtins.int] = None,
                 query_concurrency: Optional[builtins.int] = None,
                 query_per_second: Optional[builtins.int] = None,
                 replicas_per_zone: Optional[builtins.int] = None,
                 retention_period: Optional[builtins.str] = None,
                 scan_samples_per_second: Optional[builtins.int] = None,
                 scan_series_per_second: Optional[builtins.int] = None):
        """
        :param builtins.int active_series: 最大活跃时序数。
        :param builtins.int availability_zone_replicas: 可用区（az）数。
        :param Sequence[builtins.str] downsampling_periods: 降采样策略。
        :param builtins.int ingest_samples_per_second: 最大每秒写入样本数。
        :param builtins.int query_concurrency: 最大查询并发数。
        :param builtins.int query_per_second: 最大查询 QPS。
        :param builtins.int replicas_per_zone: 每个可用区（az）的数据副本数。
        :param builtins.str retention_period: 最长数据保留时间。
        :param builtins.int scan_samples_per_second: 最大每秒扫描样本数。
        :param builtins.int scan_series_per_second: 最大每秒扫描时序数。
        """
        if active_series is not None:
            pulumi.set(__self__, "active_series", active_series)
        if availability_zone_replicas is not None:
            pulumi.set(__self__, "availability_zone_replicas", availability_zone_replicas)
        if downsampling_periods is not None:
            pulumi.set(__self__, "downsampling_periods", downsampling_periods)
        if ingest_samples_per_second is not None:
            pulumi.set(__self__, "ingest_samples_per_second", ingest_samples_per_second)
        if query_concurrency is not None:
            pulumi.set(__self__, "query_concurrency", query_concurrency)
        if query_per_second is not None:
            pulumi.set(__self__, "query_per_second", query_per_second)
        if replicas_per_zone is not None:
            pulumi.set(__self__, "replicas_per_zone", replicas_per_zone)
        if retention_period is not None:
            pulumi.set(__self__, "retention_period", retention_period)
        if scan_samples_per_second is not None:
            pulumi.set(__self__, "scan_samples_per_second", scan_samples_per_second)
        if scan_series_per_second is not None:
            pulumi.set(__self__, "scan_series_per_second", scan_series_per_second)

    @property
    @pulumi.getter(name="activeSeries")
    def active_series(self) -> Optional[builtins.int]:
        """
        最大活跃时序数。
        """
        return pulumi.get(self, "active_series")

    @property
    @pulumi.getter(name="availabilityZoneReplicas")
    def availability_zone_replicas(self) -> Optional[builtins.int]:
        """
        可用区（az）数。
        """
        return pulumi.get(self, "availability_zone_replicas")

    @property
    @pulumi.getter(name="downsamplingPeriods")
    def downsampling_periods(self) -> Optional[Sequence[builtins.str]]:
        """
        降采样策略。
        """
        return pulumi.get(self, "downsampling_periods")

    @property
    @pulumi.getter(name="ingestSamplesPerSecond")
    def ingest_samples_per_second(self) -> Optional[builtins.int]:
        """
        最大每秒写入样本数。
        """
        return pulumi.get(self, "ingest_samples_per_second")

    @property
    @pulumi.getter(name="queryConcurrency")
    def query_concurrency(self) -> Optional[builtins.int]:
        """
        最大查询并发数。
        """
        return pulumi.get(self, "query_concurrency")

    @property
    @pulumi.getter(name="queryPerSecond")
    def query_per_second(self) -> Optional[builtins.int]:
        """
        最大查询 QPS。
        """
        return pulumi.get(self, "query_per_second")

    @property
    @pulumi.getter(name="replicasPerZone")
    def replicas_per_zone(self) -> Optional[builtins.int]:
        """
        每个可用区（az）的数据副本数。
        """
        return pulumi.get(self, "replicas_per_zone")

    @property
    @pulumi.getter(name="retentionPeriod")
    def retention_period(self) -> Optional[builtins.str]:
        """
        最长数据保留时间。
        """
        return pulumi.get(self, "retention_period")

    @property
    @pulumi.getter(name="scanSamplesPerSecond")
    def scan_samples_per_second(self) -> Optional[builtins.int]:
        """
        最大每秒扫描样本数。
        """
        return pulumi.get(self, "scan_samples_per_second")

    @property
    @pulumi.getter(name="scanSeriesPerSecond")
    def scan_series_per_second(self) -> Optional[builtins.int]:
        """
        最大每秒扫描时序数。
        """
        return pulumi.get(self, "scan_series_per_second")


@pulumi.output_type
class WorkspaceQuota(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "activeSeries":
            suggest = "active_series"
        elif key == "ingestSamplesPerSecond":
            suggest = "ingest_samples_per_second"
        elif key == "queryPerSecond":
            suggest = "query_per_second"
        elif key == "scanSamplesPerSecond":
            suggest = "scan_samples_per_second"
        elif key == "scanSeriesPerSecond":
            suggest = "scan_series_per_second"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkspaceQuota. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkspaceQuota.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkspaceQuota.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 active_series: Optional[builtins.int] = None,
                 ingest_samples_per_second: Optional[builtins.int] = None,
                 query_per_second: Optional[builtins.int] = None,
                 scan_samples_per_second: Optional[builtins.int] = None,
                 scan_series_per_second: Optional[builtins.int] = None):
        """
        :param builtins.int active_series: 最大活跃时序数。整数形式，默认取值范围为 1～50000000。
        :param builtins.int ingest_samples_per_second: 指标摄入速率，即最大每秒写入样本数。整数形式，默认取值范围为 1～5000000。
        :param builtins.int query_per_second: 最大查询 QPS。整数形式，默认取值范围为 1～500。
        :param builtins.int scan_samples_per_second: 最大每秒扫描样本数。整数形式，默认取值范围为 1～1000000000。
        :param builtins.int scan_series_per_second: 最大每秒扫描时序数。整数形式，默认取值范围为 1～200000。
        """
        if active_series is not None:
            pulumi.set(__self__, "active_series", active_series)
        if ingest_samples_per_second is not None:
            pulumi.set(__self__, "ingest_samples_per_second", ingest_samples_per_second)
        if query_per_second is not None:
            pulumi.set(__self__, "query_per_second", query_per_second)
        if scan_samples_per_second is not None:
            pulumi.set(__self__, "scan_samples_per_second", scan_samples_per_second)
        if scan_series_per_second is not None:
            pulumi.set(__self__, "scan_series_per_second", scan_series_per_second)

    @property
    @pulumi.getter(name="activeSeries")
    def active_series(self) -> Optional[builtins.int]:
        """
        最大活跃时序数。整数形式，默认取值范围为 1～50000000。
        """
        return pulumi.get(self, "active_series")

    @property
    @pulumi.getter(name="ingestSamplesPerSecond")
    def ingest_samples_per_second(self) -> Optional[builtins.int]:
        """
        指标摄入速率，即最大每秒写入样本数。整数形式，默认取值范围为 1～5000000。
        """
        return pulumi.get(self, "ingest_samples_per_second")

    @property
    @pulumi.getter(name="queryPerSecond")
    def query_per_second(self) -> Optional[builtins.int]:
        """
        最大查询 QPS。整数形式，默认取值范围为 1～500。
        """
        return pulumi.get(self, "query_per_second")

    @property
    @pulumi.getter(name="scanSamplesPerSecond")
    def scan_samples_per_second(self) -> Optional[builtins.int]:
        """
        最大每秒扫描样本数。整数形式，默认取值范围为 1～1000000000。
        """
        return pulumi.get(self, "scan_samples_per_second")

    @property
    @pulumi.getter(name="scanSeriesPerSecond")
    def scan_series_per_second(self) -> Optional[builtins.int]:
        """
        最大每秒扫描时序数。整数形式，默认取值范围为 1～200000。
        """
        return pulumi.get(self, "scan_series_per_second")


@pulumi.output_type
class WorkspaceTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class WorkspaceUsage(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "activeSeries":
            suggest = "active_series"
        elif key == "ingestedSamplesPerSecond":
            suggest = "ingested_samples_per_second"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkspaceUsage. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkspaceUsage.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkspaceUsage.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 active_series: Optional[builtins.int] = None,
                 ingested_samples_per_second: Optional[builtins.float] = None):
        """
        :param builtins.int active_series: 活跃时序数。
        :param builtins.float ingested_samples_per_second: 每秒写入样本数。
        """
        if active_series is not None:
            pulumi.set(__self__, "active_series", active_series)
        if ingested_samples_per_second is not None:
            pulumi.set(__self__, "ingested_samples_per_second", ingested_samples_per_second)

    @property
    @pulumi.getter(name="activeSeries")
    def active_series(self) -> Optional[builtins.int]:
        """
        活跃时序数。
        """
        return pulumi.get(self, "active_series")

    @property
    @pulumi.getter(name="ingestedSamplesPerSecond")
    def ingested_samples_per_second(self) -> Optional[builtins.float]:
        """
        每秒写入样本数。
        """
        return pulumi.get(self, "ingested_samples_per_second")


@pulumi.output_type
class GetWorkspaceInstanceTypeResult(dict):
    def __init__(__self__, *,
                 active_series: builtins.int,
                 availability_zone_replicas: builtins.int,
                 downsampling_periods: Sequence[builtins.str],
                 ingest_samples_per_second: builtins.int,
                 query_concurrency: builtins.int,
                 query_per_second: builtins.int,
                 replicas_per_zone: builtins.int,
                 retention_period: builtins.str,
                 scan_samples_per_second: builtins.int,
                 scan_series_per_second: builtins.int):
        """
        :param builtins.int active_series: 最大活跃时序数。
        :param builtins.int availability_zone_replicas: 可用区（az）数。
        :param Sequence[builtins.str] downsampling_periods: 降采样策略。
        :param builtins.int ingest_samples_per_second: 最大每秒写入样本数。
        :param builtins.int query_concurrency: 最大查询并发数。
        :param builtins.int query_per_second: 最大查询 QPS。
        :param builtins.int replicas_per_zone: 每个可用区（az）的数据副本数。
        :param builtins.str retention_period: 最长数据保留时间。
        :param builtins.int scan_samples_per_second: 最大每秒扫描样本数。
        :param builtins.int scan_series_per_second: 最大每秒扫描时序数。
        """
        pulumi.set(__self__, "active_series", active_series)
        pulumi.set(__self__, "availability_zone_replicas", availability_zone_replicas)
        pulumi.set(__self__, "downsampling_periods", downsampling_periods)
        pulumi.set(__self__, "ingest_samples_per_second", ingest_samples_per_second)
        pulumi.set(__self__, "query_concurrency", query_concurrency)
        pulumi.set(__self__, "query_per_second", query_per_second)
        pulumi.set(__self__, "replicas_per_zone", replicas_per_zone)
        pulumi.set(__self__, "retention_period", retention_period)
        pulumi.set(__self__, "scan_samples_per_second", scan_samples_per_second)
        pulumi.set(__self__, "scan_series_per_second", scan_series_per_second)

    @property
    @pulumi.getter(name="activeSeries")
    def active_series(self) -> builtins.int:
        """
        最大活跃时序数。
        """
        return pulumi.get(self, "active_series")

    @property
    @pulumi.getter(name="availabilityZoneReplicas")
    def availability_zone_replicas(self) -> builtins.int:
        """
        可用区（az）数。
        """
        return pulumi.get(self, "availability_zone_replicas")

    @property
    @pulumi.getter(name="downsamplingPeriods")
    def downsampling_periods(self) -> Sequence[builtins.str]:
        """
        降采样策略。
        """
        return pulumi.get(self, "downsampling_periods")

    @property
    @pulumi.getter(name="ingestSamplesPerSecond")
    def ingest_samples_per_second(self) -> builtins.int:
        """
        最大每秒写入样本数。
        """
        return pulumi.get(self, "ingest_samples_per_second")

    @property
    @pulumi.getter(name="queryConcurrency")
    def query_concurrency(self) -> builtins.int:
        """
        最大查询并发数。
        """
        return pulumi.get(self, "query_concurrency")

    @property
    @pulumi.getter(name="queryPerSecond")
    def query_per_second(self) -> builtins.int:
        """
        最大查询 QPS。
        """
        return pulumi.get(self, "query_per_second")

    @property
    @pulumi.getter(name="replicasPerZone")
    def replicas_per_zone(self) -> builtins.int:
        """
        每个可用区（az）的数据副本数。
        """
        return pulumi.get(self, "replicas_per_zone")

    @property
    @pulumi.getter(name="retentionPeriod")
    def retention_period(self) -> builtins.str:
        """
        最长数据保留时间。
        """
        return pulumi.get(self, "retention_period")

    @property
    @pulumi.getter(name="scanSamplesPerSecond")
    def scan_samples_per_second(self) -> builtins.int:
        """
        最大每秒扫描样本数。
        """
        return pulumi.get(self, "scan_samples_per_second")

    @property
    @pulumi.getter(name="scanSeriesPerSecond")
    def scan_series_per_second(self) -> builtins.int:
        """
        最大每秒扫描时序数。
        """
        return pulumi.get(self, "scan_series_per_second")


@pulumi.output_type
class GetWorkspaceQuotaResult(dict):
    def __init__(__self__, *,
                 active_series: builtins.int,
                 ingest_samples_per_second: builtins.int,
                 query_per_second: builtins.int,
                 scan_samples_per_second: builtins.int,
                 scan_series_per_second: builtins.int):
        """
        :param builtins.int active_series: 最大活跃时序数。整数形式，默认取值范围为 1～50000000。
        :param builtins.int ingest_samples_per_second: 指标摄入速率，即最大每秒写入样本数。整数形式，默认取值范围为 1～5000000。
        :param builtins.int query_per_second: 最大查询 QPS。整数形式，默认取值范围为 1～500。
        :param builtins.int scan_samples_per_second: 最大每秒扫描样本数。整数形式，默认取值范围为 1～1000000000。
        :param builtins.int scan_series_per_second: 最大每秒扫描时序数。整数形式，默认取值范围为 1～200000。
        """
        pulumi.set(__self__, "active_series", active_series)
        pulumi.set(__self__, "ingest_samples_per_second", ingest_samples_per_second)
        pulumi.set(__self__, "query_per_second", query_per_second)
        pulumi.set(__self__, "scan_samples_per_second", scan_samples_per_second)
        pulumi.set(__self__, "scan_series_per_second", scan_series_per_second)

    @property
    @pulumi.getter(name="activeSeries")
    def active_series(self) -> builtins.int:
        """
        最大活跃时序数。整数形式，默认取值范围为 1～50000000。
        """
        return pulumi.get(self, "active_series")

    @property
    @pulumi.getter(name="ingestSamplesPerSecond")
    def ingest_samples_per_second(self) -> builtins.int:
        """
        指标摄入速率，即最大每秒写入样本数。整数形式，默认取值范围为 1～5000000。
        """
        return pulumi.get(self, "ingest_samples_per_second")

    @property
    @pulumi.getter(name="queryPerSecond")
    def query_per_second(self) -> builtins.int:
        """
        最大查询 QPS。整数形式，默认取值范围为 1～500。
        """
        return pulumi.get(self, "query_per_second")

    @property
    @pulumi.getter(name="scanSamplesPerSecond")
    def scan_samples_per_second(self) -> builtins.int:
        """
        最大每秒扫描样本数。整数形式，默认取值范围为 1～1000000000。
        """
        return pulumi.get(self, "scan_samples_per_second")

    @property
    @pulumi.getter(name="scanSeriesPerSecond")
    def scan_series_per_second(self) -> builtins.int:
        """
        最大每秒扫描时序数。整数形式，默认取值范围为 1～200000。
        """
        return pulumi.get(self, "scan_series_per_second")


@pulumi.output_type
class GetWorkspaceTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetWorkspaceUsageResult(dict):
    def __init__(__self__, *,
                 active_series: builtins.int,
                 ingested_samples_per_second: builtins.float):
        """
        :param builtins.int active_series: 活跃时序数。
        :param builtins.float ingested_samples_per_second: 每秒写入样本数。
        """
        pulumi.set(__self__, "active_series", active_series)
        pulumi.set(__self__, "ingested_samples_per_second", ingested_samples_per_second)

    @property
    @pulumi.getter(name="activeSeries")
    def active_series(self) -> builtins.int:
        """
        活跃时序数。
        """
        return pulumi.get(self, "active_series")

    @property
    @pulumi.getter(name="ingestedSamplesPerSecond")
    def ingested_samples_per_second(self) -> builtins.float:
        """
        每秒写入样本数。
        """
        return pulumi.get(self, "ingested_samples_per_second")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VpnGatewayArgs', 'VpnGateway']

@pulumi.input_type
class VpnGatewayArgs:
    def __init__(__self__, *,
                 bandwidth: pulumi.Input[builtins.int],
                 subnet_id: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str],
                 asn: Optional[pulumi.Input[builtins.int]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dual_tunnel_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ip_stack_type: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 ipsec_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ssl_max_connections: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VpnGatewayTagArgs']]]] = None,
                 vpn_gateway_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a VpnGateway resource.
        :param pulumi.Input[builtins.int] bandwidth: VPN网关的带宽规格。
        :param pulumi.Input[builtins.str] subnet_id: VPN网关使用的端口所属子网的ID。
        :param pulumi.Input[builtins.str] vpc_id: VPN网关所在VPC的ID。
        :param pulumi.Input[builtins.int] asn: VPN网关的ASN。
        :param pulumi.Input[builtins.int] billing_type: VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        :param pulumi.Input[builtins.str] description: VPN网关的描述。
        :param pulumi.Input[builtins.bool] dual_tunnel_enabled: VPN网关是否开启双隧道模式。true：开启false：关闭
        :param pulumi.Input[builtins.str] ip_stack_type: VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        :param pulumi.Input[builtins.str] ip_version: VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        :param pulumi.Input[builtins.bool] ipsec_enabled: 是否开启IPSec功能。true：开启false：关闭。
        :param pulumi.Input[builtins.int] period: 包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        :param pulumi.Input[builtins.str] period_unit: 包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        :param pulumi.Input[builtins.str] project_name: VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        :param pulumi.Input[builtins.str] secondary_subnet_id: VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        :param pulumi.Input[builtins.bool] ssl_enabled: 是否开启SSL VPN功能。true：开启false：关闭
        :param pulumi.Input[builtins.int] ssl_max_connections: VPN网关的最大SSL连接数。
        :param pulumi.Input[builtins.str] vpn_gateway_name: VPN网关的名称。
        """
        pulumi.set(__self__, "bandwidth", bandwidth)
        pulumi.set(__self__, "subnet_id", subnet_id)
        pulumi.set(__self__, "vpc_id", vpc_id)
        if asn is not None:
            pulumi.set(__self__, "asn", asn)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dual_tunnel_enabled is not None:
            pulumi.set(__self__, "dual_tunnel_enabled", dual_tunnel_enabled)
        if ip_stack_type is not None:
            pulumi.set(__self__, "ip_stack_type", ip_stack_type)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if ipsec_enabled is not None:
            pulumi.set(__self__, "ipsec_enabled", ipsec_enabled)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if secondary_subnet_id is not None:
            pulumi.set(__self__, "secondary_subnet_id", secondary_subnet_id)
        if ssl_enabled is not None:
            pulumi.set(__self__, "ssl_enabled", ssl_enabled)
        if ssl_max_connections is not None:
            pulumi.set(__self__, "ssl_max_connections", ssl_max_connections)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpn_gateway_name is not None:
            pulumi.set(__self__, "vpn_gateway_name", vpn_gateway_name)

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Input[builtins.int]:
        """
        VPN网关的带宽规格。
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[builtins.str]:
        """
        VPN网关使用的端口所属子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        VPN网关所在VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter
    def asn(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的ASN。
        """
        return pulumi.get(self, "asn")

    @asn.setter
    def asn(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "asn", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dualTunnelEnabled")
    def dual_tunnel_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        VPN网关是否开启双隧道模式。true：开启false：关闭
        """
        return pulumi.get(self, "dual_tunnel_enabled")

    @dual_tunnel_enabled.setter
    def dual_tunnel_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dual_tunnel_enabled", value)

    @property
    @pulumi.getter(name="ipStackType")
    def ip_stack_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        """
        return pulumi.get(self, "ip_stack_type")

    @ip_stack_type.setter
    def ip_stack_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_stack_type", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="ipsecEnabled")
    def ipsec_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启IPSec功能。true：开启false：关闭。
        """
        return pulumi.get(self, "ipsec_enabled")

    @ipsec_enabled.setter
    def ipsec_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ipsec_enabled", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="secondarySubnetId")
    def secondary_subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        """
        return pulumi.get(self, "secondary_subnet_id")

    @secondary_subnet_id.setter
    def secondary_subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secondary_subnet_id", value)

    @property
    @pulumi.getter(name="sslEnabled")
    def ssl_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启SSL VPN功能。true：开启false：关闭
        """
        return pulumi.get(self, "ssl_enabled")

    @ssl_enabled.setter
    def ssl_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ssl_enabled", value)

    @property
    @pulumi.getter(name="sslMaxConnections")
    def ssl_max_connections(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的最大SSL连接数。
        """
        return pulumi.get(self, "ssl_max_connections")

    @ssl_max_connections.setter
    def ssl_max_connections(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ssl_max_connections", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VpnGatewayTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VpnGatewayTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vpnGatewayName")
    def vpn_gateway_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的名称。
        """
        return pulumi.get(self, "vpn_gateway_name")

    @vpn_gateway_name.setter
    def vpn_gateway_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpn_gateway_name", value)


@pulumi.input_type
class _VpnGatewayState:
    def __init__(__self__, *,
                 asn: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 business_status: Optional[pulumi.Input[builtins.str]] = None,
                 connection_count: Optional[pulumi.Input[builtins.int]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 deleted_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dual_tunnel_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 expired_time: Optional[pulumi.Input[builtins.str]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 ip_stack_type: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 ipsec_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 is_blocked: Optional[pulumi.Input[builtins.bool]] = None,
                 lock_reason: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_time: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 route_count: Optional[pulumi.Input[builtins.int]] = None,
                 secondary_ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ssl_max_connections: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VpnGatewayTagArgs']]]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpn_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpn_gateway_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering VpnGateway resources.
        :param pulumi.Input[builtins.int] asn: VPN网关的ASN。
        :param pulumi.Input[builtins.int] bandwidth: VPN网关的带宽规格。
        :param pulumi.Input[builtins.int] billing_type: VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        :param pulumi.Input[builtins.str] business_status: VPN网关的计费状态。Normal: 正常。FinancialLocked: 被锁定。
        :param pulumi.Input[builtins.int] connection_count: VPN网关关联IPsec连接的数量。
        :param pulumi.Input[builtins.str] create_time: 创建VPN网关的时间。
        :param pulumi.Input[builtins.str] deleted_time: 预期资源强制回收时间。
        :param pulumi.Input[builtins.str] description: VPN网关的描述。
        :param pulumi.Input[builtins.bool] dual_tunnel_enabled: VPN网关是否开启双隧道模式。true：开启false：关闭
        :param pulumi.Input[builtins.str] expired_time: VPN网关的到期时间。
        :param pulumi.Input[builtins.str] ip_address: VPN网关的公网IP地址。
        :param pulumi.Input[builtins.str] ip_stack_type: VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        :param pulumi.Input[builtins.str] ip_version: VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        :param pulumi.Input[builtins.bool] ipsec_enabled: 是否开启IPSec功能。true：开启false：关闭。
        :param pulumi.Input[builtins.bool] is_blocked: 当前资源的状态是否被封禁。true：封禁false：未封禁。
        :param pulumi.Input[builtins.str] lock_reason: VPN网关的锁定原因。financial：因欠费被锁定。security：因安全被锁定。unlock：未锁定。
        :param pulumi.Input[builtins.str] overdue_time: 资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值，否则均返回空值。
        :param pulumi.Input[builtins.int] period: 包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        :param pulumi.Input[builtins.str] period_unit: 包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        :param pulumi.Input[builtins.str] project_name: VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        :param pulumi.Input[builtins.int] route_count: VPN网关的路由条目数量。
        :param pulumi.Input[builtins.str] secondary_ip_address: VPN网关的第二个公网IP地址。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        :param pulumi.Input[builtins.str] secondary_subnet_id: VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        :param pulumi.Input[builtins.bool] ssl_enabled: 是否开启SSL VPN功能。true：开启false：关闭
        :param pulumi.Input[builtins.int] ssl_max_connections: VPN网关的最大SSL连接数。
        :param pulumi.Input[builtins.str] status: VPN网关的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        :param pulumi.Input[builtins.str] subnet_id: VPN网关使用的端口所属子网的ID。
        :param pulumi.Input[builtins.str] update_time: 更新VPN网关的时间。
        :param pulumi.Input[builtins.str] vpc_id: VPN网关所在VPC的ID。
        :param pulumi.Input[builtins.str] vpn_gateway_id: VPN网关的ID。
        :param pulumi.Input[builtins.str] vpn_gateway_name: VPN网关的名称。
        """
        if asn is not None:
            pulumi.set(__self__, "asn", asn)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if connection_count is not None:
            pulumi.set(__self__, "connection_count", connection_count)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if deleted_time is not None:
            pulumi.set(__self__, "deleted_time", deleted_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dual_tunnel_enabled is not None:
            pulumi.set(__self__, "dual_tunnel_enabled", dual_tunnel_enabled)
        if expired_time is not None:
            pulumi.set(__self__, "expired_time", expired_time)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if ip_stack_type is not None:
            pulumi.set(__self__, "ip_stack_type", ip_stack_type)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if ipsec_enabled is not None:
            pulumi.set(__self__, "ipsec_enabled", ipsec_enabled)
        if is_blocked is not None:
            pulumi.set(__self__, "is_blocked", is_blocked)
        if lock_reason is not None:
            pulumi.set(__self__, "lock_reason", lock_reason)
        if overdue_time is not None:
            pulumi.set(__self__, "overdue_time", overdue_time)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if route_count is not None:
            pulumi.set(__self__, "route_count", route_count)
        if secondary_ip_address is not None:
            pulumi.set(__self__, "secondary_ip_address", secondary_ip_address)
        if secondary_subnet_id is not None:
            pulumi.set(__self__, "secondary_subnet_id", secondary_subnet_id)
        if ssl_enabled is not None:
            pulumi.set(__self__, "ssl_enabled", ssl_enabled)
        if ssl_max_connections is not None:
            pulumi.set(__self__, "ssl_max_connections", ssl_max_connections)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vpn_gateway_id is not None:
            pulumi.set(__self__, "vpn_gateway_id", vpn_gateway_id)
        if vpn_gateway_name is not None:
            pulumi.set(__self__, "vpn_gateway_name", vpn_gateway_name)

    @property
    @pulumi.getter
    def asn(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的ASN。
        """
        return pulumi.get(self, "asn")

    @asn.setter
    def asn(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "asn", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的带宽规格。
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的计费状态。Normal: 正常。FinancialLocked: 被锁定。
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="connectionCount")
    def connection_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关关联IPsec连接的数量。
        """
        return pulumi.get(self, "connection_count")

    @connection_count.setter
    def connection_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "connection_count", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建VPN网关的时间。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        预期资源强制回收时间。
        """
        return pulumi.get(self, "deleted_time")

    @deleted_time.setter
    def deleted_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deleted_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dualTunnelEnabled")
    def dual_tunnel_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        VPN网关是否开启双隧道模式。true：开启false：关闭
        """
        return pulumi.get(self, "dual_tunnel_enabled")

    @dual_tunnel_enabled.setter
    def dual_tunnel_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dual_tunnel_enabled", value)

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的到期时间。
        """
        return pulumi.get(self, "expired_time")

    @expired_time.setter
    def expired_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expired_time", value)

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的公网IP地址。
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address", value)

    @property
    @pulumi.getter(name="ipStackType")
    def ip_stack_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        """
        return pulumi.get(self, "ip_stack_type")

    @ip_stack_type.setter
    def ip_stack_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_stack_type", value)

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_version", value)

    @property
    @pulumi.getter(name="ipsecEnabled")
    def ipsec_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启IPSec功能。true：开启false：关闭。
        """
        return pulumi.get(self, "ipsec_enabled")

    @ipsec_enabled.setter
    def ipsec_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ipsec_enabled", value)

    @property
    @pulumi.getter(name="isBlocked")
    def is_blocked(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        当前资源的状态是否被封禁。true：封禁false：未封禁。
        """
        return pulumi.get(self, "is_blocked")

    @is_blocked.setter
    def is_blocked(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_blocked", value)

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的锁定原因。financial：因欠费被锁定。security：因安全被锁定。unlock：未锁定。
        """
        return pulumi.get(self, "lock_reason")

    @lock_reason.setter
    def lock_reason(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "lock_reason", value)

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值，否则均返回空值。
        """
        return pulumi.get(self, "overdue_time")

    @overdue_time.setter
    def overdue_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_time", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="routeCount")
    def route_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的路由条目数量。
        """
        return pulumi.get(self, "route_count")

    @route_count.setter
    def route_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "route_count", value)

    @property
    @pulumi.getter(name="secondaryIpAddress")
    def secondary_ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的第二个公网IP地址。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        """
        return pulumi.get(self, "secondary_ip_address")

    @secondary_ip_address.setter
    def secondary_ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secondary_ip_address", value)

    @property
    @pulumi.getter(name="secondarySubnetId")
    def secondary_subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        """
        return pulumi.get(self, "secondary_subnet_id")

    @secondary_subnet_id.setter
    def secondary_subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secondary_subnet_id", value)

    @property
    @pulumi.getter(name="sslEnabled")
    def ssl_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启SSL VPN功能。true：开启false：关闭
        """
        return pulumi.get(self, "ssl_enabled")

    @ssl_enabled.setter
    def ssl_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ssl_enabled", value)

    @property
    @pulumi.getter(name="sslMaxConnections")
    def ssl_max_connections(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        VPN网关的最大SSL连接数。
        """
        return pulumi.get(self, "ssl_max_connections")

    @ssl_max_connections.setter
    def ssl_max_connections(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ssl_max_connections", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关使用的端口所属子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VpnGatewayTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VpnGatewayTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新VPN网关的时间。
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关所在VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的ID。
        """
        return pulumi.get(self, "vpn_gateway_id")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpn_gateway_id", value)

    @property
    @pulumi.getter(name="vpnGatewayName")
    def vpn_gateway_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        VPN网关的名称。
        """
        return pulumi.get(self, "vpn_gateway_name")

    @vpn_gateway_name.setter
    def vpn_gateway_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpn_gateway_name", value)


@pulumi.type_token("bytepluscc:vpn/vpnGateway:VpnGateway")
class VpnGateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asn: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dual_tunnel_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ip_stack_type: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 ipsec_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ssl_max_connections: Optional[pulumi.Input[builtins.int]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpnGatewayTagArgs', 'VpnGatewayTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpn_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        当您需要通过VPN连接实现私有网络与本地数据中心或其他私有网络之间的通信，您需要先创建一个VPN网关。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        vpn_vpn_gateway_demo = bytepluscc.vpn.VpnGateway("VpnVpnGatewayDemo",
            bandwidth=5,
            billing_type=2,
            description="this is a test description",
            dual_tunnel_enabled=False,
            ip_stack_type="ipv4_only",
            ip_version="ipv4",
            vpn_gateway_name="VpnVpnGatewayDemo",
            ipsec_enabled=True,
            ssl_enabled=True,
            ssl_max_connections=5,
            project_name="default",
            vpc_id="vpc-3nr6adxxxxu8931eb64y4z2",
            subnet_id="subnet-btepcsxxxxw5h0b2u6hppyd")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpn/vpnGateway:VpnGateway example "vpn_gateway_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] asn: VPN网关的ASN。
        :param pulumi.Input[builtins.int] bandwidth: VPN网关的带宽规格。
        :param pulumi.Input[builtins.int] billing_type: VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        :param pulumi.Input[builtins.str] description: VPN网关的描述。
        :param pulumi.Input[builtins.bool] dual_tunnel_enabled: VPN网关是否开启双隧道模式。true：开启false：关闭
        :param pulumi.Input[builtins.str] ip_stack_type: VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        :param pulumi.Input[builtins.str] ip_version: VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        :param pulumi.Input[builtins.bool] ipsec_enabled: 是否开启IPSec功能。true：开启false：关闭。
        :param pulumi.Input[builtins.int] period: 包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        :param pulumi.Input[builtins.str] period_unit: 包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        :param pulumi.Input[builtins.str] project_name: VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        :param pulumi.Input[builtins.str] secondary_subnet_id: VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        :param pulumi.Input[builtins.bool] ssl_enabled: 是否开启SSL VPN功能。true：开启false：关闭
        :param pulumi.Input[builtins.int] ssl_max_connections: VPN网关的最大SSL连接数。
        :param pulumi.Input[builtins.str] subnet_id: VPN网关使用的端口所属子网的ID。
        :param pulumi.Input[builtins.str] vpc_id: VPN网关所在VPC的ID。
        :param pulumi.Input[builtins.str] vpn_gateway_name: VPN网关的名称。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VpnGatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        当您需要通过VPN连接实现私有网络与本地数据中心或其他私有网络之间的通信，您需要先创建一个VPN网关。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        vpn_vpn_gateway_demo = bytepluscc.vpn.VpnGateway("VpnVpnGatewayDemo",
            bandwidth=5,
            billing_type=2,
            description="this is a test description",
            dual_tunnel_enabled=False,
            ip_stack_type="ipv4_only",
            ip_version="ipv4",
            vpn_gateway_name="VpnVpnGatewayDemo",
            ipsec_enabled=True,
            ssl_enabled=True,
            ssl_max_connections=5,
            project_name="default",
            vpc_id="vpc-3nr6adxxxxu8931eb64y4z2",
            subnet_id="subnet-btepcsxxxxw5h0b2u6hppyd")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpn/vpnGateway:VpnGateway example "vpn_gateway_id"
        ```

        :param str resource_name: The name of the resource.
        :param VpnGatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VpnGatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asn: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dual_tunnel_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ip_stack_type: Optional[pulumi.Input[builtins.str]] = None,
                 ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 ipsec_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 secondary_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 ssl_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ssl_max_connections: Optional[pulumi.Input[builtins.int]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpnGatewayTagArgs', 'VpnGatewayTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpn_gateway_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VpnGatewayArgs.__new__(VpnGatewayArgs)

            __props__.__dict__["asn"] = asn
            if bandwidth is None and not opts.urn:
                raise TypeError("Missing required property 'bandwidth'")
            __props__.__dict__["bandwidth"] = bandwidth
            __props__.__dict__["billing_type"] = billing_type
            __props__.__dict__["description"] = description
            __props__.__dict__["dual_tunnel_enabled"] = dual_tunnel_enabled
            __props__.__dict__["ip_stack_type"] = ip_stack_type
            __props__.__dict__["ip_version"] = ip_version
            __props__.__dict__["ipsec_enabled"] = ipsec_enabled
            __props__.__dict__["period"] = period
            __props__.__dict__["period_unit"] = period_unit
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["secondary_subnet_id"] = secondary_subnet_id
            __props__.__dict__["ssl_enabled"] = ssl_enabled
            __props__.__dict__["ssl_max_connections"] = ssl_max_connections
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["vpn_gateway_name"] = vpn_gateway_name
            __props__.__dict__["business_status"] = None
            __props__.__dict__["connection_count"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["deleted_time"] = None
            __props__.__dict__["expired_time"] = None
            __props__.__dict__["ip_address"] = None
            __props__.__dict__["is_blocked"] = None
            __props__.__dict__["lock_reason"] = None
            __props__.__dict__["overdue_time"] = None
            __props__.__dict__["route_count"] = None
            __props__.__dict__["secondary_ip_address"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["update_time"] = None
            __props__.__dict__["vpn_gateway_id"] = None
        super(VpnGateway, __self__).__init__(
            'bytepluscc:vpn/vpnGateway:VpnGateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            asn: Optional[pulumi.Input[builtins.int]] = None,
            bandwidth: Optional[pulumi.Input[builtins.int]] = None,
            billing_type: Optional[pulumi.Input[builtins.int]] = None,
            business_status: Optional[pulumi.Input[builtins.str]] = None,
            connection_count: Optional[pulumi.Input[builtins.int]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            deleted_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            dual_tunnel_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            expired_time: Optional[pulumi.Input[builtins.str]] = None,
            ip_address: Optional[pulumi.Input[builtins.str]] = None,
            ip_stack_type: Optional[pulumi.Input[builtins.str]] = None,
            ip_version: Optional[pulumi.Input[builtins.str]] = None,
            ipsec_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            is_blocked: Optional[pulumi.Input[builtins.bool]] = None,
            lock_reason: Optional[pulumi.Input[builtins.str]] = None,
            overdue_time: Optional[pulumi.Input[builtins.str]] = None,
            period: Optional[pulumi.Input[builtins.int]] = None,
            period_unit: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            route_count: Optional[pulumi.Input[builtins.int]] = None,
            secondary_ip_address: Optional[pulumi.Input[builtins.str]] = None,
            secondary_subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            ssl_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            ssl_max_connections: Optional[pulumi.Input[builtins.int]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpnGatewayTagArgs', 'VpnGatewayTagArgsDict']]]]] = None,
            update_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            vpn_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            vpn_gateway_name: Optional[pulumi.Input[builtins.str]] = None) -> 'VpnGateway':
        """
        Get an existing VpnGateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] asn: VPN网关的ASN。
        :param pulumi.Input[builtins.int] bandwidth: VPN网关的带宽规格。
        :param pulumi.Input[builtins.int] billing_type: VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        :param pulumi.Input[builtins.str] business_status: VPN网关的计费状态。Normal: 正常。FinancialLocked: 被锁定。
        :param pulumi.Input[builtins.int] connection_count: VPN网关关联IPsec连接的数量。
        :param pulumi.Input[builtins.str] create_time: 创建VPN网关的时间。
        :param pulumi.Input[builtins.str] deleted_time: 预期资源强制回收时间。
        :param pulumi.Input[builtins.str] description: VPN网关的描述。
        :param pulumi.Input[builtins.bool] dual_tunnel_enabled: VPN网关是否开启双隧道模式。true：开启false：关闭
        :param pulumi.Input[builtins.str] expired_time: VPN网关的到期时间。
        :param pulumi.Input[builtins.str] ip_address: VPN网关的公网IP地址。
        :param pulumi.Input[builtins.str] ip_stack_type: VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        :param pulumi.Input[builtins.str] ip_version: VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        :param pulumi.Input[builtins.bool] ipsec_enabled: 是否开启IPSec功能。true：开启false：关闭。
        :param pulumi.Input[builtins.bool] is_blocked: 当前资源的状态是否被封禁。true：封禁false：未封禁。
        :param pulumi.Input[builtins.str] lock_reason: VPN网关的锁定原因。financial：因欠费被锁定。security：因安全被锁定。unlock：未锁定。
        :param pulumi.Input[builtins.str] overdue_time: 资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值，否则均返回空值。
        :param pulumi.Input[builtins.int] period: 包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        :param pulumi.Input[builtins.str] period_unit: 包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        :param pulumi.Input[builtins.str] project_name: VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        :param pulumi.Input[builtins.int] route_count: VPN网关的路由条目数量。
        :param pulumi.Input[builtins.str] secondary_ip_address: VPN网关的第二个公网IP地址。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        :param pulumi.Input[builtins.str] secondary_subnet_id: VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        :param pulumi.Input[builtins.bool] ssl_enabled: 是否开启SSL VPN功能。true：开启false：关闭
        :param pulumi.Input[builtins.int] ssl_max_connections: VPN网关的最大SSL连接数。
        :param pulumi.Input[builtins.str] status: VPN网关的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        :param pulumi.Input[builtins.str] subnet_id: VPN网关使用的端口所属子网的ID。
        :param pulumi.Input[builtins.str] update_time: 更新VPN网关的时间。
        :param pulumi.Input[builtins.str] vpc_id: VPN网关所在VPC的ID。
        :param pulumi.Input[builtins.str] vpn_gateway_id: VPN网关的ID。
        :param pulumi.Input[builtins.str] vpn_gateway_name: VPN网关的名称。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VpnGatewayState.__new__(_VpnGatewayState)

        __props__.__dict__["asn"] = asn
        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["billing_type"] = billing_type
        __props__.__dict__["business_status"] = business_status
        __props__.__dict__["connection_count"] = connection_count
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["deleted_time"] = deleted_time
        __props__.__dict__["description"] = description
        __props__.__dict__["dual_tunnel_enabled"] = dual_tunnel_enabled
        __props__.__dict__["expired_time"] = expired_time
        __props__.__dict__["ip_address"] = ip_address
        __props__.__dict__["ip_stack_type"] = ip_stack_type
        __props__.__dict__["ip_version"] = ip_version
        __props__.__dict__["ipsec_enabled"] = ipsec_enabled
        __props__.__dict__["is_blocked"] = is_blocked
        __props__.__dict__["lock_reason"] = lock_reason
        __props__.__dict__["overdue_time"] = overdue_time
        __props__.__dict__["period"] = period
        __props__.__dict__["period_unit"] = period_unit
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["route_count"] = route_count
        __props__.__dict__["secondary_ip_address"] = secondary_ip_address
        __props__.__dict__["secondary_subnet_id"] = secondary_subnet_id
        __props__.__dict__["ssl_enabled"] = ssl_enabled
        __props__.__dict__["ssl_max_connections"] = ssl_max_connections
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vpn_gateway_id"] = vpn_gateway_id
        __props__.__dict__["vpn_gateway_name"] = vpn_gateway_name
        return VpnGateway(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def asn(self) -> pulumi.Output[builtins.int]:
        """
        VPN网关的ASN。
        """
        return pulumi.get(self, "asn")

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[builtins.int]:
        """
        VPN网关的带宽规格。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Output[builtins.int]:
        """
        VPN网关的计费类型。1：包年包月。2：按量计费（按固定规格）
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的计费状态。Normal: 正常。FinancialLocked: 被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="connectionCount")
    def connection_count(self) -> pulumi.Output[builtins.int]:
        """
        VPN网关关联IPsec连接的数量。
        """
        return pulumi.get(self, "connection_count")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        创建VPN网关的时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> pulumi.Output[builtins.str]:
        """
        预期资源强制回收时间。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dualTunnelEnabled")
    def dual_tunnel_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        VPN网关是否开启双隧道模式。true：开启false：关闭
        """
        return pulumi.get(self, "dual_tunnel_enabled")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的到期时间。
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的公网IP地址。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="ipStackType")
    def ip_stack_type(self) -> pulumi.Output[builtins.str]:
        """
        VPN 网关的协议类型。ipv4*only：IPv4协议类型。ipv6*only：IPv6协议类型。ipv4_ipv6：双栈协议类型。
        """
        return pulumi.get(self, "ip_stack_type")

    @property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的IP地址类型。ipv4：IPv4地址类型。ipv6：IPv6地址类型。
        """
        return pulumi.get(self, "ip_version")

    @property
    @pulumi.getter(name="ipsecEnabled")
    def ipsec_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启IPSec功能。true：开启false：关闭。
        """
        return pulumi.get(self, "ipsec_enabled")

    @property
    @pulumi.getter(name="isBlocked")
    def is_blocked(self) -> pulumi.Output[builtins.bool]:
        """
        当前资源的状态是否被封禁。true：封禁false：未封禁。
        """
        return pulumi.get(self, "is_blocked")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的锁定原因。financial：因欠费被锁定。security：因安全被锁定。unlock：未锁定。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> pulumi.Output[builtins.str]:
        """
        资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值，否则均返回空值。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[builtins.int]:
        """
        包年包月类型VPN网关购买的时长，默认“1”。当PeriodUnit传入值为Month，Period取值范围：1~9、12、24、36。当PeriodUnit传入值为Year，Period取值范围：1～3。
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> pulumi.Output[builtins.str]:
        """
        包年包月类型VPN网关购买时长的单位，默认“Month”。Month：月Year：年
        """
        return pulumi.get(self, "period_unit")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关所属的项目。不填默认为default，即创建的资源属于default项目。您可调用ListProjects查询当前账号下项目的信息。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="routeCount")
    def route_count(self) -> pulumi.Output[builtins.int]:
        """
        VPN网关的路由条目数量。
        """
        return pulumi.get(self, "route_count")

    @property
    @pulumi.getter(name="secondaryIpAddress")
    def secondary_ip_address(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的第二个公网IP地址。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        """
        return pulumi.get(self, "secondary_ip_address")

    @property
    @pulumi.getter(name="secondarySubnetId")
    def secondary_subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关实例关联的第二个子网的ID。仅双隧道模式的VPN网关实例返回该参数，单隧道模式的VPN网关实例不返回该参数。
        """
        return pulumi.get(self, "secondary_subnet_id")

    @property
    @pulumi.getter(name="sslEnabled")
    def ssl_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启SSL VPN功能。true：开启false：关闭
        """
        return pulumi.get(self, "ssl_enabled")

    @property
    @pulumi.getter(name="sslMaxConnections")
    def ssl_max_connections(self) -> pulumi.Output[builtins.int]:
        """
        VPN网关的最大SSL连接数。
        """
        return pulumi.get(self, "ssl_max_connections")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的状态。Creating: 创建中Deleting: 删除中Pending：配置中Available：可用
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关使用的端口所属子网的ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.VpnGatewayTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[builtins.str]:
        """
        更新VPN网关的时间。
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关所在VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的ID。
        """
        return pulumi.get(self, "vpn_gateway_id")

    @property
    @pulumi.getter(name="vpnGatewayName")
    def vpn_gateway_name(self) -> pulumi.Output[builtins.str]:
        """
        VPN网关的名称。
        """
        return pulumi.get(self, "vpn_gateway_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetRouteTableResult',
    'AwaitableGetRouteTableResult',
    'get_route_table',
    'get_route_table_output',
]

@pulumi.output_type
class GetRouteTableResult:
    """
    A collection of values returned by getRouteTable.
    """
    def __init__(__self__, account_id=None, associate_type=None, created_time=None, custom_route_entries=None, description=None, id=None, ipv4_gateway_id=None, ipv6_gateway_id=None, project_name=None, route_table_id=None, route_table_name=None, route_table_type=None, subnet_ids=None, system_route_entries=None, tags=None, updated_time=None, vpc_id=None, vpc_name=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if associate_type and not isinstance(associate_type, str):
            raise TypeError("Expected argument 'associate_type' to be a str")
        pulumi.set(__self__, "associate_type", associate_type)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if custom_route_entries and not isinstance(custom_route_entries, list):
            raise TypeError("Expected argument 'custom_route_entries' to be a list")
        pulumi.set(__self__, "custom_route_entries", custom_route_entries)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ipv4_gateway_id and not isinstance(ipv4_gateway_id, str):
            raise TypeError("Expected argument 'ipv4_gateway_id' to be a str")
        pulumi.set(__self__, "ipv4_gateway_id", ipv4_gateway_id)
        if ipv6_gateway_id and not isinstance(ipv6_gateway_id, str):
            raise TypeError("Expected argument 'ipv6_gateway_id' to be a str")
        pulumi.set(__self__, "ipv6_gateway_id", ipv6_gateway_id)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if route_table_id and not isinstance(route_table_id, str):
            raise TypeError("Expected argument 'route_table_id' to be a str")
        pulumi.set(__self__, "route_table_id", route_table_id)
        if route_table_name and not isinstance(route_table_name, str):
            raise TypeError("Expected argument 'route_table_name' to be a str")
        pulumi.set(__self__, "route_table_name", route_table_name)
        if route_table_type and not isinstance(route_table_type, str):
            raise TypeError("Expected argument 'route_table_type' to be a str")
        pulumi.set(__self__, "route_table_type", route_table_type)
        if subnet_ids and not isinstance(subnet_ids, list):
            raise TypeError("Expected argument 'subnet_ids' to be a list")
        pulumi.set(__self__, "subnet_ids", subnet_ids)
        if system_route_entries and not isinstance(system_route_entries, list):
            raise TypeError("Expected argument 'system_route_entries' to be a list")
        pulumi.set(__self__, "system_route_entries", system_route_entries)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_name and not isinstance(vpc_name, str):
            raise TypeError("Expected argument 'vpc_name' to be a str")
        pulumi.set(__self__, "vpc_name", vpc_name)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        路由表所属账号的ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="associateType")
    def associate_type(self) -> builtins.str:
        """
        创建路由表输入的关联类型。1、Subnet：子网关联。2、Gateway：网关关联。
        """
        return pulumi.get(self, "associate_type")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        路由表创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customRouteEntries")
    def custom_route_entries(self) -> Sequence['outputs.GetRouteTableCustomRouteEntryResult']:
        """
        路由表关联的自定义路由条目列表。
        """
        return pulumi.get(self, "custom_route_entries")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        路由表描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipv4GatewayId")
    def ipv4_gateway_id(self) -> builtins.str:
        """
        关联路由表的IPv4网关ID。
        """
        return pulumi.get(self, "ipv4_gateway_id")

    @property
    @pulumi.getter(name="ipv6GatewayId")
    def ipv6_gateway_id(self) -> builtins.str:
        """
        关联路由表的IPv6网关ID。
        """
        return pulumi.get(self, "ipv6_gateway_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        路由表所属项目的名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="routeTableId")
    def route_table_id(self) -> builtins.str:
        """
        路由表ID。
        """
        return pulumi.get(self, "route_table_id")

    @property
    @pulumi.getter(name="routeTableName")
    def route_table_name(self) -> builtins.str:
        """
        路由表名称。
        """
        return pulumi.get(self, "route_table_name")

    @property
    @pulumi.getter(name="routeTableType")
    def route_table_type(self) -> builtins.str:
        """
        路由表类型。1、Custom：自定义路由表。2、System：系统路由表。
        """
        return pulumi.get(self, "route_table_type")

    @property
    @pulumi.getter(name="subnetIds")
    def subnet_ids(self) -> Sequence[builtins.str]:
        """
        关联的子网的ID列表。
        """
        return pulumi.get(self, "subnet_ids")

    @property
    @pulumi.getter(name="systemRouteEntries")
    def system_route_entries(self) -> Sequence['outputs.GetRouteTableSystemRouteEntryResult']:
        """
        路由表关联的系统默认路由条目列表。
        """
        return pulumi.get(self, "system_route_entries")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetRouteTableTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        路由表更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        路由表所属VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> builtins.str:
        """
        VPC的名称。
        """
        return pulumi.get(self, "vpc_name")


class AwaitableGetRouteTableResult(GetRouteTableResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRouteTableResult(
            account_id=self.account_id,
            associate_type=self.associate_type,
            created_time=self.created_time,
            custom_route_entries=self.custom_route_entries,
            description=self.description,
            id=self.id,
            ipv4_gateway_id=self.ipv4_gateway_id,
            ipv6_gateway_id=self.ipv6_gateway_id,
            project_name=self.project_name,
            route_table_id=self.route_table_id,
            route_table_name=self.route_table_name,
            route_table_type=self.route_table_type,
            subnet_ids=self.subnet_ids,
            system_route_entries=self.system_route_entries,
            tags=self.tags,
            updated_time=self.updated_time,
            vpc_id=self.vpc_id,
            vpc_name=self.vpc_name)


def get_route_table(id: Optional[builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRouteTableResult:
    """
    Data Source schema for Byteplus::VPC::RouteTable


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getRouteTable:getRouteTable', __args__, opts=opts, typ=GetRouteTableResult).value

    return AwaitableGetRouteTableResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        associate_type=pulumi.get(__ret__, 'associate_type'),
        created_time=pulumi.get(__ret__, 'created_time'),
        custom_route_entries=pulumi.get(__ret__, 'custom_route_entries'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        ipv4_gateway_id=pulumi.get(__ret__, 'ipv4_gateway_id'),
        ipv6_gateway_id=pulumi.get(__ret__, 'ipv6_gateway_id'),
        project_name=pulumi.get(__ret__, 'project_name'),
        route_table_id=pulumi.get(__ret__, 'route_table_id'),
        route_table_name=pulumi.get(__ret__, 'route_table_name'),
        route_table_type=pulumi.get(__ret__, 'route_table_type'),
        subnet_ids=pulumi.get(__ret__, 'subnet_ids'),
        system_route_entries=pulumi.get(__ret__, 'system_route_entries'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        vpc_name=pulumi.get(__ret__, 'vpc_name'))
def get_route_table_output(id: Optional[pulumi.Input[builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRouteTableResult]:
    """
    Data Source schema for Byteplus::VPC::RouteTable


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getRouteTable:getRouteTable', __args__, opts=opts, typ=GetRouteTableResult)
    return __ret__.apply(lambda __response__: GetRouteTableResult(
        account_id=pulumi.get(__response__, 'account_id'),
        associate_type=pulumi.get(__response__, 'associate_type'),
        created_time=pulumi.get(__response__, 'created_time'),
        custom_route_entries=pulumi.get(__response__, 'custom_route_entries'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        ipv4_gateway_id=pulumi.get(__response__, 'ipv4_gateway_id'),
        ipv6_gateway_id=pulumi.get(__response__, 'ipv6_gateway_id'),
        project_name=pulumi.get(__response__, 'project_name'),
        route_table_id=pulumi.get(__response__, 'route_table_id'),
        route_table_name=pulumi.get(__response__, 'route_table_name'),
        route_table_type=pulumi.get(__response__, 'route_table_type'),
        subnet_ids=pulumi.get(__response__, 'subnet_ids'),
        system_route_entries=pulumi.get(__response__, 'system_route_entries'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        vpc_name=pulumi.get(__response__, 'vpc_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NetworkAclArgs', 'NetworkAcl']

@pulumi.input_type
class NetworkAclArgs:
    def __init__(__self__, *,
                 vpc_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 egress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclEgressAclEntryArgs']]]] = None,
                 ingress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclIngressAclEntryArgs']]]] = None,
                 network_acl_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclResourceArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclTagArgs']]]] = None):
        """
        The set of arguments for constructing a NetworkAcl resource.
        :param pulumi.Input[builtins.str] vpc_id: 网络ACL所属VPC的ID。
        :param pulumi.Input[builtins.str] description: 网络ACL描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] network_acl_name: 网络ACL名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        :param pulumi.Input[builtins.str] project_name: 网络ACL所属项目的名称。不填默认加入default项目。
        """
        pulumi.set(__self__, "vpc_id", vpc_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if egress_acl_entries is not None:
            pulumi.set(__self__, "egress_acl_entries", egress_acl_entries)
        if ingress_acl_entries is not None:
            pulumi.set(__self__, "ingress_acl_entries", ingress_acl_entries)
        if network_acl_name is not None:
            pulumi.set(__self__, "network_acl_name", network_acl_name)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        网络ACL所属VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络ACL描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="egressAclEntries")
    def egress_acl_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclEgressAclEntryArgs']]]]:
        return pulumi.get(self, "egress_acl_entries")

    @egress_acl_entries.setter
    def egress_acl_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclEgressAclEntryArgs']]]]):
        pulumi.set(self, "egress_acl_entries", value)

    @property
    @pulumi.getter(name="ingressAclEntries")
    def ingress_acl_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclIngressAclEntryArgs']]]]:
        return pulumi.get(self, "ingress_acl_entries")

    @ingress_acl_entries.setter
    def ingress_acl_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclIngressAclEntryArgs']]]]):
        pulumi.set(self, "ingress_acl_entries", value)

    @property
    @pulumi.getter(name="networkAclName")
    def network_acl_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络ACL名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        """
        return pulumi.get(self, "network_acl_name")

    @network_acl_name.setter
    def network_acl_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_acl_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络ACL所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclResourceArgs']]]]:
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclResourceArgs']]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _NetworkAclState:
    def __init__(__self__, *,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 default_egress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclDefaultEgressAclEntryArgs']]]] = None,
                 default_ingress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclDefaultIngressAclEntryArgs']]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 egress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclEgressAclEntryArgs']]]] = None,
                 ingress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclIngressAclEntryArgs']]]] = None,
                 network_acl_id: Optional[pulumi.Input[builtins.str]] = None,
                 network_acl_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclResourceArgs']]]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering NetworkAcl resources.
        :param pulumi.Input[builtins.str] created_time: 网络ACL的创建时间。
        :param pulumi.Input[builtins.str] description: 网络ACL描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] network_acl_id: 网络ACL的ID。
        :param pulumi.Input[builtins.str] network_acl_name: 网络ACL名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        :param pulumi.Input[builtins.str] project_name: 网络ACL所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.str] status: 网络ACL的状态。Available：可用，Creating：创建中
        :param pulumi.Input[builtins.str] updated_time: 网络ACL的更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 网络ACL所属VPC的ID。
        """
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if default_egress_acl_entries is not None:
            pulumi.set(__self__, "default_egress_acl_entries", default_egress_acl_entries)
        if default_ingress_acl_entries is not None:
            pulumi.set(__self__, "default_ingress_acl_entries", default_ingress_acl_entries)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if egress_acl_entries is not None:
            pulumi.set(__self__, "egress_acl_entries", egress_acl_entries)
        if ingress_acl_entries is not None:
            pulumi.set(__self__, "ingress_acl_entries", ingress_acl_entries)
        if network_acl_id is not None:
            pulumi.set(__self__, "network_acl_id", network_acl_id)
        if network_acl_name is not None:
            pulumi.set(__self__, "network_acl_name", network_acl_name)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络ACL的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="defaultEgressAclEntries")
    def default_egress_acl_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclDefaultEgressAclEntryArgs']]]]:
        return pulumi.get(self, "default_egress_acl_entries")

    @default_egress_acl_entries.setter
    def default_egress_acl_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclDefaultEgressAclEntryArgs']]]]):
        pulumi.set(self, "default_egress_acl_entries", value)

    @property
    @pulumi.getter(name="defaultIngressAclEntries")
    def default_ingress_acl_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclDefaultIngressAclEntryArgs']]]]:
        return pulumi.get(self, "default_ingress_acl_entries")

    @default_ingress_acl_entries.setter
    def default_ingress_acl_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclDefaultIngressAclEntryArgs']]]]):
        pulumi.set(self, "default_ingress_acl_entries", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络ACL描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="egressAclEntries")
    def egress_acl_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclEgressAclEntryArgs']]]]:
        return pulumi.get(self, "egress_acl_entries")

    @egress_acl_entries.setter
    def egress_acl_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclEgressAclEntryArgs']]]]):
        pulumi.set(self, "egress_acl_entries", value)

    @property
    @pulumi.getter(name="ingressAclEntries")
    def ingress_acl_entries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclIngressAclEntryArgs']]]]:
        return pulumi.get(self, "ingress_acl_entries")

    @ingress_acl_entries.setter
    def ingress_acl_entries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclIngressAclEntryArgs']]]]):
        pulumi.set(self, "ingress_acl_entries", value)

    @property
    @pulumi.getter(name="networkAclId")
    def network_acl_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络ACL的ID。
        """
        return pulumi.get(self, "network_acl_id")

    @network_acl_id.setter
    def network_acl_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_acl_id", value)

    @property
    @pulumi.getter(name="networkAclName")
    def network_acl_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络ACL名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        """
        return pulumi.get(self, "network_acl_name")

    @network_acl_name.setter
    def network_acl_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_acl_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络ACL所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclResourceArgs']]]]:
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclResourceArgs']]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络ACL的状态。Available：可用，Creating：创建中
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkAclTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络ACL的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络ACL所属VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)


@pulumi.type_token("bytepluscc:vpc/networkAcl:NetworkAcl")
class NetworkAcl(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 egress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclEgressAclEntryArgs', 'NetworkAclEgressAclEntryArgsDict']]]]] = None,
                 ingress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclIngressAclEntryArgs', 'NetworkAclIngressAclEntryArgsDict']]]]] = None,
                 network_acl_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclResourceArgs', 'NetworkAclResourceArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclTagArgs', 'NetworkAclTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        网络ACL用于控制子网的出入流量，其基于白名单原理设计，出入子网的流量必须被网络ACL规则允许才能放通。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/networkAcl:NetworkAcl example "network_acl_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 网络ACL描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] network_acl_name: 网络ACL名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        :param pulumi.Input[builtins.str] project_name: 网络ACL所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.str] vpc_id: 网络ACL所属VPC的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkAclArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        网络ACL用于控制子网的出入流量，其基于白名单原理设计，出入子网的流量必须被网络ACL规则允许才能放通。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/networkAcl:NetworkAcl example "network_acl_id"
        ```

        :param str resource_name: The name of the resource.
        :param NetworkAclArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkAclArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 egress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclEgressAclEntryArgs', 'NetworkAclEgressAclEntryArgsDict']]]]] = None,
                 ingress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclIngressAclEntryArgs', 'NetworkAclIngressAclEntryArgsDict']]]]] = None,
                 network_acl_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclResourceArgs', 'NetworkAclResourceArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclTagArgs', 'NetworkAclTagArgsDict']]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkAclArgs.__new__(NetworkAclArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["egress_acl_entries"] = egress_acl_entries
            __props__.__dict__["ingress_acl_entries"] = ingress_acl_entries
            __props__.__dict__["network_acl_name"] = network_acl_name
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["resources"] = resources
            __props__.__dict__["tags"] = tags
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["created_time"] = None
            __props__.__dict__["default_egress_acl_entries"] = None
            __props__.__dict__["default_ingress_acl_entries"] = None
            __props__.__dict__["network_acl_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(NetworkAcl, __self__).__init__(
            'bytepluscc:vpc/networkAcl:NetworkAcl',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            default_egress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclDefaultEgressAclEntryArgs', 'NetworkAclDefaultEgressAclEntryArgsDict']]]]] = None,
            default_ingress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclDefaultIngressAclEntryArgs', 'NetworkAclDefaultIngressAclEntryArgsDict']]]]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            egress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclEgressAclEntryArgs', 'NetworkAclEgressAclEntryArgsDict']]]]] = None,
            ingress_acl_entries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclIngressAclEntryArgs', 'NetworkAclIngressAclEntryArgsDict']]]]] = None,
            network_acl_id: Optional[pulumi.Input[builtins.str]] = None,
            network_acl_name: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            resources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclResourceArgs', 'NetworkAclResourceArgsDict']]]]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkAclTagArgs', 'NetworkAclTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None) -> 'NetworkAcl':
        """
        Get an existing NetworkAcl resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: 网络ACL的创建时间。
        :param pulumi.Input[builtins.str] description: 网络ACL描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.str] network_acl_id: 网络ACL的ID。
        :param pulumi.Input[builtins.str] network_acl_name: 网络ACL名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        :param pulumi.Input[builtins.str] project_name: 网络ACL所属项目的名称。不填默认加入default项目。
        :param pulumi.Input[builtins.str] status: 网络ACL的状态。Available：可用，Creating：创建中
        :param pulumi.Input[builtins.str] updated_time: 网络ACL的更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 网络ACL所属VPC的ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkAclState.__new__(_NetworkAclState)

        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["default_egress_acl_entries"] = default_egress_acl_entries
        __props__.__dict__["default_ingress_acl_entries"] = default_ingress_acl_entries
        __props__.__dict__["description"] = description
        __props__.__dict__["egress_acl_entries"] = egress_acl_entries
        __props__.__dict__["ingress_acl_entries"] = ingress_acl_entries
        __props__.__dict__["network_acl_id"] = network_acl_id
        __props__.__dict__["network_acl_name"] = network_acl_name
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["resources"] = resources
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpc_id"] = vpc_id
        return NetworkAcl(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        网络ACL的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="defaultEgressAclEntries")
    def default_egress_acl_entries(self) -> pulumi.Output[Sequence['outputs.NetworkAclDefaultEgressAclEntry']]:
        return pulumi.get(self, "default_egress_acl_entries")

    @property
    @pulumi.getter(name="defaultIngressAclEntries")
    def default_ingress_acl_entries(self) -> pulumi.Output[Sequence['outputs.NetworkAclDefaultIngressAclEntry']]:
        return pulumi.get(self, "default_ingress_acl_entries")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        网络ACL描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="egressAclEntries")
    def egress_acl_entries(self) -> pulumi.Output[Sequence['outputs.NetworkAclEgressAclEntry']]:
        return pulumi.get(self, "egress_acl_entries")

    @property
    @pulumi.getter(name="ingressAclEntries")
    def ingress_acl_entries(self) -> pulumi.Output[Sequence['outputs.NetworkAclIngressAclEntry']]:
        return pulumi.get(self, "ingress_acl_entries")

    @property
    @pulumi.getter(name="networkAclId")
    def network_acl_id(self) -> pulumi.Output[builtins.str]:
        """
        网络ACL的ID。
        """
        return pulumi.get(self, "network_acl_id")

    @property
    @pulumi.getter(name="networkAclName")
    def network_acl_name(self) -> pulumi.Output[builtins.str]:
        """
        网络ACL名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        """
        return pulumi.get(self, "network_acl_name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        网络ACL所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Output[Sequence['outputs.NetworkAclResource']]:
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        网络ACL的状态。Available：可用，Creating：创建中
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.NetworkAclTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        网络ACL的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        网络ACL所属VPC的ID。
        """
        return pulumi.get(self, "vpc_id")

